#include <stdint.h>
#include <stdbool.h>
#include <string.h>
#include "twis.h"

#include "nrf_drv_twis.h"
#include "nrf_gpio.h"

#include "nrf_log.h"
#include "nrf_log_ctrl.h"
#include "nrf_log_default_backends.h"


static const nrf_drv_twis_t m_twis = NRF_DRV_TWIS_INSTANCE(0);

static uint8_t m_rxbuff[1+8];

//=============================================================================
//=============================================================================
static void twis_event_handler(nrf_drv_twis_evt_t const * const p_event)
{
  switch (p_event->type)
  {
    case(TWIS_EVT_READ_REQ):
    {
      if (p_event->data.buf_req)
      {
        NRF_LOG_INFO("TWIS_EVT_READ_REQ");
//                ees_readBegin();

      }
    }
    break;

    case(TWIS_EVT_READ_DONE):
    {
      NRF_LOG_INFO("TWIS_EVT_READ_DONE");
//      ees_readEnd(p_event->data.tx_amount);
    }
    break;

    case(TWIS_EVT_WRITE_REQ):
    {
      NRF_LOG_INFO("TWIS_EVT_WRITE_REQ");
      if (p_event->data.buf_req)
      {
        (void)nrf_drv_twis_rx_prepare(&m_twis, m_rxbuff, sizeof(m_rxbuff));
      }
    }
    break;

    case(TWIS_EVT_WRITE_DONE):
    {
      NRF_LOG_INFO("TWIS_EVT_WRITE_DONE");
//         ees_writeEnd(p_event->data.rx_amount);
    }
    break;

    case TWIS_EVT_READ_ERROR:
    case TWIS_EVT_WRITE_ERROR:
    case TWIS_EVT_GENERAL_ERROR:
    {
      NRF_LOG_INFO("TWIS_EVT_ERR");
//            m_error_flag = true;
    }
    break;

    default:
    {
    }
    break;
  }
}



//=============================================================================
//=============================================================================
uint32_t init_twis(void)
{
  uint32_t ret;
  const nrf_drv_twis_config_t config =
  {
    .addr               = {I2C_S_ADDR, 0},
    .scl                = I2C_S_SCL_PIN,
//    .scl_pull           = TWIS_DEFAULT_CONFIG_SCL_PULL,
    .scl_pull           = NRF_GPIO_PIN_PULLUP,
    .sda                = I2C_S_SDA_PIN,
//    .sda_pull           = TWIS_DEFAULT_CONFIG_SDA_PULL,
    .sda_pull           = NRF_GPIO_PIN_PULLUP,
    .interrupt_priority = TWIS_DEFAULT_CONFIG_IRQ_PRIORITY
    };

    /* Init TWIS */
    do
    {
      ret = nrf_drv_twis_init(&m_twis, &config, twis_event_handler);
      if (NRF_SUCCESS != ret)
      {
        break;
      }

      nrf_drv_twis_enable(&m_twis);
    }while (0);
    return ret;
}

